@@ -618,6 +618,11 @@ bool KeyframeModel::removeAllKeyframes(Fun &undo, Fun &redo)
     Fun local_undo = []() { return true; };
     Fun local_redo = []() { return true; };
     int kfrCount = (int)m_keyframeList.size() - 1;
+    if (kfrCount <= 0) {
+        // Nothing to do
+        UPDATE_UNDO_REDO(local_redo, local_undo, undo, redo);
+        return true;
+    }
     // we trigger only one global remove/insertrow event
     Fun update_redo_start = [this, kfrCount]() {
         beginRemoveRows(QModelIndex(), 1, kfrCount);
@@ -736,7 +741,7 @@ QString KeyframeModel::getRotoProperty() const
 {
     QJsonDocument doc;
     if (auto ptr = m_model.lock()) {
-        int in = 0; //ptr->data(m_index, AssetParameterModel::ParentInRole).toInt();
+        int in = 0; // ptr->data(m_index, AssetParameterModel::ParentInRole).toInt();
         int out = ptr->data(m_index, AssetParameterModel::ParentDurationRole).toInt();
         QMap<QString, QVariant> map;
         for (const auto &keyframe : m_keyframeList) {
@@ -756,11 +761,13 @@ void KeyframeModel::parseAnimProperty(const QString &prop)
     removeAllKeyframes(undo, redo);
     int in = 0;
     int out = 0;
+    bool useOpacity = true;
     Mlt::Properties mlt_prop;
     if (auto ptr = m_model.lock()) {
         in = ptr->data(m_index, AssetParameterModel::ParentInRole).toInt();
         out = ptr->data(m_index, AssetParameterModel::ParentDurationRole).toInt();
         ptr->passProperties(mlt_prop);
+        useOpacity = ptr->data(m_index, AssetParameterModel::OpacityRole).toBool();
     }
     mlt_prop.set("key", prop.toUtf8().constData());
     // This is a fake query to force the animation to be parsed
@@ -782,7 +789,11 @@ void KeyframeModel::parseAnimProperty(const QString &prop)
         switch (m_paramType) {
         case ParamType::AnimatedRect: {
             mlt_rect rect = mlt_prop.anim_get_rect("key", frame);
-            value = QVariant(QStringLiteral("%1 %2 %3 %4 %5").arg(rect.x).arg(rect.y).arg(rect.w).arg(rect.h).arg(locale.toString(rect.o)));
+            if (useOpacity) {
+                value = QVariant(QStringLiteral("%1 %2 %3 %4 %5").arg(rect.x).arg(rect.y).arg(rect.w).arg(rect.h).arg(locale.toString(rect.o)));
+            } else {
+                value = QVariant(QStringLiteral("%1 %2 %3 %4").arg(rect.x).arg(rect.y).arg(rect.w).arg(rect.h));
+            }
             break;
         }
         default:
@@ -814,9 +825,13 @@ void KeyframeModel::resetAnimProperty(const QString &prop)
     Mlt::Properties mlt_prop;
     QLocale locale;
     int in = 0;
+    bool useOpacity = true;
     if (auto ptr = m_model.lock()) {
         in = ptr->data(m_index, AssetParameterModel::ParentInRole).toInt();
         ptr->passProperties(mlt_prop);
+        if (m_paramType == ParamType::AnimatedRect) {
+            useOpacity = ptr->data(m_index, AssetParameterModel::OpacityRole).toBool();
+        }
     }
     mlt_prop.set("key", prop.toUtf8().constData());
     // This is a fake query to force the animation to be parsed
@@ -837,7 +852,11 @@ void KeyframeModel::resetAnimProperty(const QString &prop)
         switch (m_paramType) {
         case ParamType::AnimatedRect: {
             mlt_rect rect = mlt_prop.anim_get_rect("key", frame);
-            value = QVariant(QStringLiteral("%1 %2 %3 %4 %5").arg(rect.x).arg(rect.y).arg(rect.w).arg(rect.h).arg(locale.toString(rect.o)));
+            if (useOpacity) {
+                value = QVariant(QStringLiteral("%1 %2 %3 %4 %5").arg(rect.x).arg(rect.y).arg(rect.w).arg(rect.h).arg(locale.toString(rect.o)));
+            } else {
+                value = QVariant(QStringLiteral("%1 %2 %3 %4").arg(rect.x).arg(rect.y).arg(rect.w).arg(rect.h));
+            }
             break;
         }
         default:
@@ -950,8 +969,12 @@ QVariant KeyframeModel::getInterpolatedValue(const GenTime &pos) const
     --prev;
     // We now have surrounding keyframes, we use mlt to compute the value
     Mlt::Properties prop;
+    bool useOpacity = true;
     if (auto ptr = m_model.lock()) {
         ptr->passProperties(prop);
+        if (m_paramType == ParamType::AnimatedRect) {
+            useOpacity = ptr->data(m_index, AssetParameterModel::OpacityRole).toBool();
+        }
     }
     QLocale locale;
     int p = pos.frames(pCore->getCurrentFps());
@@ -969,10 +992,12 @@ QVariant KeyframeModel::getInterpolatedValue(const GenTime &pos) const
             rect.y = vals.at(1).toInt();
             rect.w = vals.at(2).toInt();
             rect.h = vals.at(3).toInt();
-            if (vals.count() > 4) {
-                rect.o = locale.toDouble(vals.at(4));
-            } else {
-                rect.o = 1;
+            if (useOpacity) {
+                if (vals.count()) {
+                    rect.o = locale.toDouble(vals.at(4));
+                } else {
+                    rect.o = 1;
+                }
             }
             prop.anim_set("keyframe", rect, prev->first.frames(pCore->getCurrentFps()), next->first.frames(pCore->getCurrentFps()),
                           convertToMltType(prev->second.first));
@@ -984,23 +1009,34 @@ QVariant KeyframeModel::getInterpolatedValue(const GenTime &pos) const
             rect.y = vals.at(1).toInt();
             rect.w = vals.at(2).toInt();
             rect.h = vals.at(3).toInt();
-            if (vals.count() > 4) {
-                rect.o = locale.toDouble(vals.at(4));
-            } else {
-                rect.o = 1;
+            if (useOpacity) {
+                if (vals.count() > 4) {
+                    rect.o = locale.toDouble(vals.at(4));
+                } else {
+                    rect.o = 1;
+                }
             }
             prop.anim_set("keyframe", rect, next->first.frames(pCore->getCurrentFps()), next->first.frames(pCore->getCurrentFps()),
                           convertToMltType(next->second.first));
         }
         mlt_rect rect = prop.anim_get_rect("keyframe", p);
-        const QString res = QStringLiteral("%1 %2 %3 %4 %5").arg((int)rect.x).arg((int)rect.y).arg((int)rect.w).arg((int)rect.h).arg(locale.toString(rect.o));
+        QString res = QStringLiteral("%1 %2 %3 %4").arg((int)rect.x).arg((int)rect.y).arg((int)rect.w).arg((int)rect.h);
+        if (useOpacity) {
+            res.append(QStringLiteral(" %1").arg(locale.toString(rect.o)));
+        }
         return QVariant(res);
     } else if (m_paramType == ParamType::Roto_spline) {
         // interpolate
         QSize frame = pCore->getCurrentFrameSize();
         QList<BPoint> p1 = RotoHelper::getPoints(prev->second.second, frame);
-        qreal relPos = (p - prev->first.frames(pCore->getCurrentFps())) / (qreal)(((next->first - prev->first).frames(pCore->getCurrentFps())) + 1);
         QList<BPoint> p2 = RotoHelper::getPoints(next->second.second, frame);
+        // relPos should be in [0,1]:
+        // - equal to 0 on prev keyframe
+        // - equal to 1 on next keyframe
+        qreal relPos = 0;
+        if (next->first != prev->first) {
+            relPos = (p - prev->first.frames(pCore->getCurrentFps())) / (qreal)(((next->first - prev->first).frames(pCore->getCurrentFps())));
+        }
         int count = qMin(p1.count(), p2.count());
         QList<QVariant> vlist;
         for (int i = 0; i < count; ++i) {
@@ -1167,7 +1203,7 @@ const QString KeyframeModel::getAnimationStringWithOffset(std::shared_ptr<AssetP
     (void)mlt_prop.anim_get_rect("key", 0);
     Mlt::Animation anim = mlt_prop.get_animation("key");
     if (offset > 0) {
-        for (int i = anim.key_count() - 1; i >=0 ; --i) {
+        for (int i = anim.key_count() - 1; i >= 0; --i) {
             int pos = anim.key_get_frame(i) + offset;
             anim.key_set_frame(i, pos);
         }
