@@ -132,7 +132,7 @@ public:
 
     bool rename(const QString &name, int column) override;
 
-    QDomElement toXml(QDomDocument &document, bool includeMeta = false) override;
+    QDomElement toXml(QDomDocument &document, bool includeMeta = false, bool includeProfile = true) override;
 
     QVariant getData(DataType type) const override;
 
@@ -236,8 +236,6 @@ protected:
     void deregisterTimelineClip(int clipId);
 
     void emitProducerChanged(const QString &id, const std::shared_ptr<Mlt::Producer> &producer) override { emit producerChanged(id, producer); };
-    /** @brief Replace instance of this clip in timeline */
-    void updateChildProducers();
     void replaceInTimeline();
     void connectEffectStack() override;
 
