@@ -132,7 +132,7 @@ std::shared_ptr<Mlt::Producer> LoadJob::loadPlaylist(QString &resource)
     if (pCore->getCurrentProfile()->isCompatible(xmlProfile.get())) {
         // We can use the "xml" producer since profile is the same (using it with different profiles corrupts the project.
         // Beware that "consumer" currently crashes on audio mixes!
-        resource.prepend(QStringLiteral("xml:"));
+        //resource.prepend(QStringLiteral("xml:"));
     } else {
         // This is currently crashing so I guess we'd better reject it for now
         qDebug() << "////// ERROR, INCOMPATIBLE PROFILE: " << resource;
@@ -140,7 +140,7 @@ std::shared_ptr<Mlt::Producer> LoadJob::loadPlaylist(QString &resource)
         // path.prepend(QStringLiteral("consumer:"));
     }
     pCore->getCurrentProfile()->set_explicit(1);
-    return std::make_shared<Mlt::Producer>(pCore->getCurrentProfile()->profile(), nullptr, resource.toUtf8().constData());
+    return std::make_shared<Mlt::Producer>(pCore->getCurrentProfile()->profile(), "xml", resource.toUtf8().constData());
 }
 
 void LoadJob::checkProfile(const QString &clipId, const QDomElement &xml, const std::shared_ptr<Mlt::Producer> &producer)
@@ -267,9 +267,35 @@ bool LoadJob::startJob()
     case ClipType::QText:
         m_producer = loadResource(m_resource, QStringLiteral("qtext:"));
         break;
-    case ClipType::Playlist:
+    case ClipType::Playlist: {
         m_producer = loadPlaylist(m_resource);
+        if (m_resource.endsWith(QLatin1String(".kdenlive"))) {
+            QFile f(m_resource);
+            QDomDocument doc;
+            doc.setContent(&f, false);
+            f.close();
+            QDomElement pl = doc.documentElement().firstChildElement(QStringLiteral("playlist"));
+            if (!pl.isNull()) {
+                QString offsetData = Xml::getXmlProperty(pl, QStringLiteral("kdenlive:docproperties.seekOffset"));
+                if (offsetData.isEmpty() && Xml::getXmlProperty(pl, QStringLiteral("kdenlive:docproperties.version")) == QLatin1String("0.98")) {
+                    offsetData = QStringLiteral("30000");
+                }
+                if (!offsetData.isEmpty()) {
+                    bool ok = false;
+                    int offset = offsetData.toInt(&ok);
+                    qDebug()<<" / / /GET OFFSET DATA: "<<offset;
+                    if (ok) {
+                        offset = m_producer->get_playtime() - offset - 1;
+                        m_producer->set("out", offset - 1);
+                        m_producer->set("length", offset);
+                    }
+                }
+            } else {
+                qDebug()<<":_______\n______<nEMPTY PLAYLIST\n----";
+            }
+        }
         break;
+    }
     case ClipType::SlideShow:
     default:
         if (!service.isEmpty()) {
@@ -474,7 +500,7 @@ void LoadJob::processMultiStream()
     QLabel *lab1 = new QLabel(i18n("Additional streams for clip\n %1", m_resource), mainWidget);
     mainLayout->addWidget(lab1);
     QList<QGroupBox *> groupList;
-    QList<KComboBox *> comboList;
+    QList<QComboBox *> comboList;
     // We start loading the list at 1, video index 0 should already be loaded
     for (int j = 1; j < m_video_list.count(); ++j) {
         m_producer->set("video_index", m_video_list.at(j));
@@ -492,7 +518,7 @@ void LoadJob::processMultiStream()
         iconLabel->setPixmap(QPixmap::fromImage(thumb));
         vh->addWidget(iconLabel);
         if (m_audio_list.count() > 1) {
-            auto *cb = new KComboBox(mainWidget);
+            auto *cb = new QComboBox(mainWidget);
             mainLayout->addWidget(cb);
             for (int k = 0; k < m_audio_list.count(); ++k) {
                 cb->addItem(i18n("Audio stream %1", m_audio_list.at(k)), m_audio_list.at(k));
@@ -503,6 +529,7 @@ void LoadJob::processMultiStream()
         }
         mainLayout->addWidget(streamFrame);
     }
+    m_producer->set("video_index", m_video_list.at(0));
     mainLayout->addWidget(buttonBox);
     if (dialog->exec() == QDialog::Accepted) {
         // import selected streams
@@ -518,8 +545,8 @@ void LoadJob::processMultiStream()
                 addStream(vindex, aindex, undo, redo);
             }
         }
+        pCore->pushUndo(undo, redo, i18n("Add additional streams for clip"));
     }
-    pCore->pushUndo(undo, redo, i18n("Add additional streams for clip"));
 }
 
 bool LoadJob::commitResult(Fun &undo, Fun &redo)
