@@ -42,6 +42,7 @@
 #include "kdenlive_debug.h"
 #include <KDBusService>
 #include <KIconTheme>
+#include <QResource>
 #include <QApplication>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
@@ -65,22 +66,39 @@ int main(int argc, char *argv[])
     QCoreApplication::setAttribute(Qt::AA_X11InitThreads);
 #endif
 
-#ifdef Q_OS_WIN
-    qputenv("KDE_FORK_SLAVES", "1");
-    QString path = qApp->applicationDirPath() + QLatin1Char(';') + qgetenv("PATH");
-    qputenv("PATH", path.toUtf8().constData());
-#endif
-
     Logger::init();
     QApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("kdenlive"));
     app.setOrganizationDomain(QStringLiteral("kde.org"));
     app.setWindowIcon(QIcon(QStringLiteral(":/pics/kdenlive.png")));
     KLocalizedString::setApplicationDomain("kdenlive");
+
+#ifdef Q_OS_WIN
+    qputenv("KDE_FORK_SLAVES", "1");
+    QString path = qApp->applicationDirPath() + QLatin1Char(';') + qgetenv("PATH");
+    qputenv("PATH", path.toUtf8().constData());
+
+    const QStringList themes {"/icons/breeze/breeze-icons.rcc", "/icons/breeze-dark/breeze-icons-dark.rcc"};
+    for(const QString theme : themes ) {
+        const QString themePath = QStandardPaths::locate(QStandardPaths::AppDataLocation, theme);
+        if (!themePath.isEmpty()) {
+            const QString iconSubdir = theme.left(theme.lastIndexOf('/'));
+            if (QResource::registerResource(themePath, iconSubdir)) {
+                if (QFileInfo::exists(QLatin1Char(':') + iconSubdir + QStringLiteral("/index.theme"))) {
+                    qDebug() << "Loaded icon theme:" << theme;
+                } else {
+                    qWarning() << "No index.theme found in" << theme;
+                    QResource::unregisterResource(themePath, iconSubdir);
+                }
+            } else {
+                qWarning() << "Invalid rcc file" << theme;
+            }
+        }
+    }
+#endif
     KSharedConfigPtr config = KSharedConfig::openConfig();
     KConfigGroup grp(config, "unmanaged");
-    KConfigGroup initialGroup(config, "version");
-    if (!initialGroup.exists()) {
+    if (!grp.exists()) {
         QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
         if (env.contains(QStringLiteral("XDG_CURRENT_DESKTOP")) && env.value(QStringLiteral("XDG_CURRENT_DESKTOP")).toLower() == QLatin1String("kde")) {
             qCDebug(KDENLIVE_LOG) << "KDE Desktop detected, using system icons";
@@ -101,7 +119,6 @@ int main(int argc, char *argv[])
 
     // Init DBus services
     KDBusService programDBusService;
-
     bool forceBreeze = grp.readEntry("force_breeze", QVariant(false)).toBool();
     if (forceBreeze) {
         bool darkBreeze = grp.readEntry("use_dark_breeze", QVariant(false)).toBool();
@@ -182,7 +199,6 @@ int main(int argc, char *argv[])
                                      1, 0,                       // major and minor version of the import
                                      "ProducerType",             // name in QML
                                      "Error: only enums");
-    QString mltPath = parser.value(QStringLiteral("mlt-path"));
     if (parser.value(QStringLiteral("mlt-log")) == QStringLiteral("verbose")) {
         mlt_log_set_level(MLT_LOG_VERBOSE);
     } else if (parser.value(QStringLiteral("mlt-log")) == QStringLiteral("debug")) {
@@ -196,8 +212,7 @@ int main(int argc, char *argv[])
         QUrl startup = QUrl::fromLocalFile(currentPath.endsWith(QDir::separator()) ? currentPath : currentPath + QDir::separator());
         url = startup.resolved(url);
     }
-    //qApp->processEvents();
-    Core::build(mltPath);
+    Core::build(!parser.value(QStringLiteral("config")).isEmpty(), parser.value(QStringLiteral("mlt-path")));
     pCore->initGUI(url);
     //delete splash;
     //splash->endSplash();
