@@ -84,7 +84,7 @@ int ClipModel::construct(const std::shared_ptr<TimelineModel> &parent, const QSt
     TRACE_CONSTR(clip.get(), parent, binClipId, id, state, speed);
     clip->setClipState_lambda(state)();
     parent->registerClip(clip);
-    clip->m_clipMarkerModel->setReferenceModel(binClip->getMarkerModel());
+    clip->m_clipMarkerModel->setReferenceModel(binClip->getMarkerModel(), speed);
     return id;
 }
 
@@ -114,7 +114,7 @@ int ClipModel::construct(const std::shared_ptr<TimelineModel> &parent, const QSt
     clip->setClipState_lambda(state)();
     clip->m_effectStack->importEffects(producer, state, result.second);
     parent->registerClip(clip);
-    clip->m_clipMarkerModel->setReferenceModel(binClip->getMarkerModel());
+    clip->m_clipMarkerModel->setReferenceModel(binClip->getMarkerModel(), speed);
     return id;
 }
 
@@ -176,6 +176,9 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
     }
     if (m_currentTrackId != -1) {
         if (auto ptr = m_parent.lock()) {
+            if (ptr->getTrackById(m_currentTrackId)->isLocked()) {
+                return false;
+            }
             track_operation = ptr->getTrackById(m_currentTrackId)->requestClipResize_lambda(m_id, inPoint, outPoint, right);
         } else {
             qDebug() << "Error : Moving clip failed because parent timeline is not available anymore";
@@ -374,7 +377,6 @@ void ClipModel::refreshProducerFromBin(PlaylistState::ClipState state, double sp
     QWriteLocker locker(&m_lock);
     int in = getIn();
     int out = getOut();
-    qDebug() << "refresh " << speed << m_speed << in << out;
     if (!qFuzzyCompare(speed, m_speed) && !qFuzzyCompare(speed, 0.)) {
         in = in * std::abs(m_speed / speed);
         out = in + getPlaytime() - 1;
@@ -413,7 +415,7 @@ bool ClipModel::useTimewarpProducer(double speed, Fun &undo, Fun &redo)
     std::function<bool(void)> local_redo = []() { return true; };
     double previousSpeed = getSpeed();
     int oldDuration = getPlaytime();
-    int newDuration = int(double(oldDuration) * std::abs(previousSpeed / speed));
+    int newDuration = int(double(oldDuration) * std::abs(previousSpeed / speed) + 0.5);
     int oldOut = getOut();
     int oldIn = getIn();
     auto operation = useTimewarpProducer_lambda(speed);
@@ -430,7 +432,8 @@ bool ClipModel::useTimewarpProducer(double speed, Fun &undo, Fun &redo)
     }
     if (operation()) {
         UPDATE_UNDO_REDO(operation, reverse, local_undo, local_redo);
-        bool res = requestResize(newDuration, true, local_undo, local_redo, true);
+        // When calculating duration, result can be a few frames longer than possible duration so adjust
+        bool res = requestResize(qMin(newDuration, getMaxDuration()), true, local_undo, local_redo, true);
         if (!res) {
             local_undo();
             return false;
@@ -541,7 +544,7 @@ void ClipModel::setCurrentTrackId(int tid, bool finalMove)
     MoveableItem::setCurrentTrackId(tid, finalMove);
     if (registerSnap) {
         if (auto ptr = m_parent.lock()) {
-            m_clipMarkerModel->registerSnapModel(ptr->m_snaps, getPosition(), getIn(), getOut());
+            m_clipMarkerModel->registerSnapModel(ptr->m_snaps, getPosition(), getIn(), getOut(), m_speed);
         }
     }
 
@@ -658,11 +661,16 @@ QDomElement ClipModel::toXml(QDomDocument &document)
         container.setAttribute(QStringLiteral("track"), trackId);
         if (ptr->isAudioTrack(getCurrentTrackId())) {
             container.setAttribute(QStringLiteral("audioTrack"), 1);
-            int mirrorId = ptr->getMirrorVideoTrackId(m_currentTrackId);
-            if (mirrorId > -1) {
-                mirrorId = ptr->getTrackPosition(mirrorId);
+            int partner = ptr->getClipSplitPartner(m_id);
+            if (partner != -1) {
+                int mirrorId = ptr->getMirrorVideoTrackId(m_currentTrackId);
+                if (mirrorId > -1) {
+                    mirrorId = ptr->getTrackPosition(mirrorId);
+                }
+                container.setAttribute(QStringLiteral("mirrorTrack"), mirrorId);
+            } else {
+                container.setAttribute(QStringLiteral("mirrorTrack"), QStringLiteral("-1"));
             }
-            container.setAttribute(QStringLiteral("mirrorTrack"), mirrorId);
         }
     }
     container.setAttribute(QStringLiteral("speed"), m_speed);
@@ -722,6 +730,16 @@ void ClipModel::setOffset(int offset)
     }
 }
 
+void ClipModel::setGrab(bool grab)
+{
+    QWriteLocker locker(&m_lock);
+    m_grabbed = grab;
+    if (auto ptr = m_parent.lock()) {
+        QModelIndex ix = ptr->makeClipIndexFromID(m_id);
+        ptr->dataChanged(ix, ix, {TimelineModel::GrabbedRole});
+    }
+}
+
 void ClipModel::clearOffset()
 {
     if (m_positionOffset != 0) {
@@ -733,3 +751,12 @@ int ClipModel::getOffset() const
 {
     return m_positionOffset;
 }
+
+int ClipModel::getMaxDuration() const
+{
+    READ_LOCK();
+    if (m_endlessResize) {
+        return -1;
+    }
+    return m_producer->get_length();
+}
