@@ -197,6 +197,7 @@ QHash<int, QByteArray> TimelineItemModel::roleNames() const
     roles[FakePositionRole] = "fakePosition";
     roles[StartRole] = "start";
     roles[DurationRole] = "duration";
+    roles[MaxDurationRole] = "maxDuration";
     roles[MarkersRole] = "markers";
     roles[KeyframesRole] = "keyframeModel";
     roles[ShowKeyframesRole] = "showKeyframes";
@@ -314,6 +315,8 @@ QVariant TimelineItemModel::data(const QModelIndex &index, int role) const
             return clip->getPosition();
         case DurationRole:
             return clip->getPlaytime();
+        case MaxDurationRole:
+            return clip->getMaxDuration();
         case GroupedRole:
             return m_groups->isInGroup(id);
         case EffectNamesRole:
@@ -359,7 +362,7 @@ QVariant TimelineItemModel::data(const QModelIndex &index, int role) const
         case TrackTagRole:
             return getTrackTagById(id);
         case IsLockedRole:
-            return getTrackById_const(id)->getProperty("kdenlive:locked_track").toInt() == 1;
+            return getTrackById_const(id)->isLocked();
         case HeightRole: {
             int collapsed = getTrackById_const(id)->getProperty("kdenlive:collapsed").toInt();
             if (collapsed > 0) {
