@@ -82,6 +82,12 @@ TimelineController::TimelineController(QObject *parent)
 
 TimelineController::~TimelineController()
 {
+    prepareClose();
+}
+
+void TimelineController::prepareClose()
+{
+    // Delete timeline preview before resetting model so that removing clips from timeline doesn't invalidate
     delete m_timelinePreview;
     m_timelinePreview = nullptr;
 }
@@ -337,7 +343,10 @@ int TimelineController::insertNewComposition(int tid, int clipId, int offset, co
         }
     }
     position = qMin(minimum + clip_duration - 1, position);
-    int duration = m_model->getTrackById_const(tid)->suggestCompositionLength(position);
+    int duration = pCore->currentDoc()->getFramePos(KdenliveSettings::transition_duration());
+    if (duration == 0) {
+        duration = m_model->getTrackById_const(tid)->suggestCompositionLength(position);
+    }
     int lowerVideoTrackId = m_model->getPreviousVideoTrackIndex(tid);
     bool revert = offset > clip_duration / 2;
     if (lowerVideoTrackId > 0) {
@@ -405,7 +414,7 @@ void TimelineController::deleteSelectedClips()
     m_model->requestItemDeletion(*sel.begin());
 }
 
-int TimelineController::getMainSelectedClip()
+int TimelineController::getMainSelectedItem(bool restrictToCurrentPos, bool allowComposition)
 {
     auto sel = m_model->getCurrentSelection();
     if (sel.empty() || sel.size() > 2) {
@@ -418,6 +427,11 @@ int TimelineController::getMainSelectedClip()
             return -1;
         }
     }
+    if (!restrictToCurrentPos) {
+        if (m_model->isClip(itemId) || (allowComposition && m_model->isComposition(itemId))) {
+            return itemId;
+        }
+    }
     if (m_model->isClip(itemId)) {
         int position = timelinePosition();
         int start = m_model->getClipPosition(itemId);
@@ -443,12 +457,16 @@ void TimelineController::copyItem()
     m_model->requestSetSelection(selectedIds);
 }
 
-bool TimelineController::pasteItem()
+bool TimelineController::pasteItem(int position, int tid)
 {
     QClipboard *clipboard = QApplication::clipboard();
     QString txt = clipboard->text();
-    int tid = getMouseTrack();
-    int position = getMousePos();
+    if (tid == -1) {
+        tid = getMouseTrack();
+    }
+    if (position == -1) {
+        position = getMousePos();
+    }
     if (tid == -1) {
         tid = m_activeTrack;
     }
@@ -553,12 +571,17 @@ void TimelineController::showConfig(int page, int tab)
 
 void TimelineController::gotoNextSnap()
 {
-    setPosition(m_model->getNextSnapPos(timelinePosition()));
+    int nextSnap = m_model->getNextSnapPos(timelinePosition());
+    if (nextSnap > timelinePosition()) {
+        setPosition(nextSnap);
+    }
 }
 
 void TimelineController::gotoPreviousSnap()
 {
-    setPosition(m_model->getPreviousSnapPos(timelinePosition()));
+    if (timelinePosition() > 0) {
+        setPosition(m_model->getPreviousSnapPos(timelinePosition()));
+    }
 }
 
 void TimelineController::groupSelection()
@@ -597,7 +620,7 @@ void TimelineController::setInPoint()
 {
     if (dragOperationRunning()) {
         // Don't allow timeline operation while drag in progress
-        qDebug()<<"Cannot operate while dragging";
+        qDebug() << "Cannot operate while dragging";
         return;
     }
 
@@ -624,7 +647,7 @@ void TimelineController::setOutPoint()
 {
     if (dragOperationRunning()) {
         // Don't allow timeline operation while drag in progress
-        qDebug()<<"Cannot operate while dragging";
+        qDebug() << "Cannot operate while dragging";
         return;
     }
     int cursorPos = timelinePosition();
@@ -644,45 +667,58 @@ void TimelineController::setOutPoint()
 void TimelineController::editMarker(int cid, int position)
 {
     Q_ASSERT(m_model->isClip(cid));
+    double speed = m_model->getClipSpeed(cid);
     if (position == -1) {
-        position = timelinePosition();
+        // Calculate marker position relative to timeline cursor
+        position = timelinePosition() - m_model->getClipPosition(cid) + m_model->getClipIn(cid);
+        position = position * speed;
     }
-    if (position < m_model->getClipPosition(cid) || position > (m_model->getClipPosition(cid) + m_model->getClipPlaytime(cid))) {
+    if (position < (m_model->getClipIn(cid) * speed) || position > (m_model->getClipIn(cid) * speed + m_model->getClipPlaytime(cid))) {
         pCore->displayMessage(i18n("Cannot find clip to edit marker"), InformationMessage, 500);
         return;
     }
     std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(getClipBinId(cid));
-    GenTime pos(position - m_model->getClipPosition(cid) + m_model->getClipIn(cid), pCore->getCurrentFps());
-    clip->getMarkerModel()->editMarkerGui(pos, qApp->activeWindow(), false, clip.get());
+    if (clip->getMarkerModel()->hasMarker(position)) {
+        GenTime pos(position, pCore->getCurrentFps());
+        clip->getMarkerModel()->editMarkerGui(pos, qApp->activeWindow(), false, clip.get());
+    } else {
+        pCore->displayMessage(i18n("Cannot find clip to edit marker"), InformationMessage, 500);
+    }
 }
 
 void TimelineController::addMarker(int cid, int position)
 {
     Q_ASSERT(m_model->isClip(cid));
+    double speed = m_model->getClipSpeed(cid);
     if (position == -1) {
-        position = timelinePosition();
+        // Calculate marker position relative to timeline cursor
+        position = timelinePosition() - m_model->getClipPosition(cid) + m_model->getClipIn(cid);
+        position = position * speed;
     }
-    if (position < m_model->getClipPosition(cid) || position > (m_model->getClipPosition(cid) + m_model->getClipPlaytime(cid))) {
-        pCore->displayMessage(i18n("Cannot find clip to add marker"), InformationMessage, 500);
+    if (position < (m_model->getClipIn(cid) * speed) || position > (m_model->getClipIn(cid) * speed + m_model->getClipPlaytime(cid))) {
+        pCore->displayMessage(i18n("Cannot find clip to edit marker"), InformationMessage, 500);
         return;
     }
     std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(getClipBinId(cid));
-    GenTime pos(position - m_model->getClipPosition(cid) + m_model->getClipIn(cid), pCore->getCurrentFps());
+    GenTime pos(position, pCore->getCurrentFps());
     clip->getMarkerModel()->editMarkerGui(pos, qApp->activeWindow(), true, clip.get());
 }
 
 void TimelineController::addQuickMarker(int cid, int position)
 {
     Q_ASSERT(m_model->isClip(cid));
+    double speed = m_model->getClipSpeed(cid);
     if (position == -1) {
-        position = timelinePosition();
+        // Calculate marker position relative to timeline cursor
+        position = timelinePosition() - m_model->getClipPosition(cid) + m_model->getClipIn(cid);
+        position = position * speed;
     }
-    if (position < m_model->getClipPosition(cid) || position > (m_model->getClipPosition(cid) + m_model->getClipPlaytime(cid))) {
-        pCore->displayMessage(i18n("Cannot find clip to add marker"), InformationMessage, 500);
+    if (position < (m_model->getClipIn(cid) * speed) || position > (m_model->getClipIn(cid) * speed + m_model->getClipPlaytime(cid))) {
+        pCore->displayMessage(i18n("Cannot find clip to edit marker"), InformationMessage, 500);
         return;
     }
     std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(getClipBinId(cid));
-    GenTime pos(position - m_model->getClipPosition(cid) + m_model->getClipIn(cid), pCore->getCurrentFps());
+    GenTime pos(position, pCore->getCurrentFps());
     CommentedTime marker(pos, pCore->currentDoc()->timecode().getDisplayTimecode(pos, false), KdenliveSettings::default_marker_type());
     clip->getMarkerModel()->addMarker(marker.time(), marker.comment(), marker.markerType());
 }
@@ -690,15 +726,18 @@ void TimelineController::addQuickMarker(int cid, int position)
 void TimelineController::deleteMarker(int cid, int position)
 {
     Q_ASSERT(m_model->isClip(cid));
+    double speed = m_model->getClipSpeed(cid);
     if (position == -1) {
-        position = timelinePosition();
+        // Calculate marker position relative to timeline cursor
+        position = timelinePosition() - m_model->getClipPosition(cid) + m_model->getClipIn(cid);
+        position = position * speed;
     }
-    if (position < m_model->getClipPosition(cid) || position > (m_model->getClipPosition(cid) + m_model->getClipPlaytime(cid))) {
-        pCore->displayMessage(i18n("Cannot find clip to remove marker"), InformationMessage, 500);
+    if (position < (m_model->getClipIn(cid) * speed) || position > (m_model->getClipIn(cid) * speed + m_model->getClipPlaytime(cid))) {
+        pCore->displayMessage(i18n("Cannot find clip to edit marker"), InformationMessage, 500);
         return;
     }
     std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(getClipBinId(cid));
-    GenTime pos(position - m_model->getClipPosition(cid) + m_model->getClipIn(cid), pCore->getCurrentFps());
+    GenTime pos(position, pCore->getCurrentFps());
     clip->getMarkerModel()->removeMarker(pos);
 }
 
@@ -1403,20 +1442,27 @@ void TimelineController::invalidateZone(int in, int out)
 
 void TimelineController::changeItemSpeed(int clipId, double speed)
 {
+    if (clipId == -1) {
+        clipId = getMainSelectedItem(false, true);
+    }
+    if (clipId == -1) {
+        pCore->displayMessage(i18n("No item to edit"), InformationMessage, 500);
+        return;
+    }
     if (qFuzzyCompare(speed, -1)) {
         speed = 100 * m_model->getClipSpeed(clipId);
         double duration = m_model->getItemPlaytime(clipId);
         // this is the max speed so that the clip is at least one frame long
         double maxSpeed = 100. * duration * qAbs(m_model->getClipSpeed(clipId));
         // this is the min speed so that the clip doesn't bump into the next one on track
-        double minSpeed = 100. * duration * qAbs(m_model->getClipSpeed(clipId)) / (duration + double(m_model->getBlankSizeNearClip(clipId, true)) - 1);
+        double minSpeed = 100. * duration * qAbs(m_model->getClipSpeed(clipId)) / (duration + double(m_model->getBlankSizeNearClip(clipId, true)));
 
         // if there is a split partner, we must also take it into account
         int partner = m_model->getClipSplitPartner(clipId);
         if (partner != -1) {
             double duration2 = m_model->getItemPlaytime(partner);
             double maxSpeed2 = 100. * duration2 * qAbs(m_model->getClipSpeed(partner));
-            double minSpeed2 = 100. * duration2 * qAbs(m_model->getClipSpeed(partner)) / (duration2 + double(m_model->getBlankSizeNearClip(partner, true)) - 1);
+            double minSpeed2 = 100. * duration2 * qAbs(m_model->getClipSpeed(partner)) / (duration2 + double(m_model->getBlankSizeNearClip(partner, true)));
             minSpeed = std::max(minSpeed, minSpeed2);
             maxSpeed = std::min(maxSpeed, maxSpeed2);
         }
@@ -1734,29 +1780,21 @@ void TimelineController::switchTrackLock(bool applyToAll)
     if (!applyToAll) {
         // apply to active track only
         bool locked = m_model->getTrackById_const(m_activeTrack)->isLocked();
-        m_model->setTrackProperty(m_activeTrack, QStringLiteral("kdenlive:locked_track"), locked ? QStringLiteral("0") : QStringLiteral("1"));
+        m_model->setTrackLockedState(m_activeTrack, !locked);
     } else {
         // Invert track lock
-        // Get track states first
-        QMap<int, bool> trackLockState;
-        int unlockedTracksCount = 0;
-        int tracksCount = m_model->getTracksCount();
-        for (int track = tracksCount - 1; track >= 0; track--) {
-            int trackIx = m_model->getTrackIndexFromPosition(track);
-            bool isLocked = m_model->getTrackById_const(trackIx)->getProperty("kdenlive:locked_track").toInt() == 1;
-            if (!isLocked) {
-                unlockedTracksCount++;
+        const auto ids = m_model->getAllTracksIds();
+        // count the number of tracks to be locked
+        int toBeLockedCount =
+            std::accumulate(ids.begin(), ids.end(), 0, [this](int s, int id) { return s + (m_model->getTrackById_const(id)->isLocked() ? 0 : 1); });
+        bool leaveOneUnlocked = toBeLockedCount == m_model->getTracksCount();
+        for (const int id : ids) {
+            // leave active track unlocked
+            if (leaveOneUnlocked && id == m_activeTrack) {
+                continue;
             }
-            trackLockState.insert(trackIx, isLocked);
-        }
-        if (unlockedTracksCount == tracksCount) {
-            // do not lock all tracks, leave active track unlocked
-            trackLockState.insert(m_activeTrack, true);
-        }
-        QMapIterator<int, bool> i(trackLockState);
-        while (i.hasNext()) {
-            i.next();
-            m_model->setTrackProperty(i.key(), QStringLiteral("kdenlive:locked_track"), i.value() ? QStringLiteral("0") : QStringLiteral("1"));
+            bool isLocked = m_model->getTrackById_const(id)->isLocked();
+            m_model->setTrackLockedState(id, !isLocked);
         }
     }
 }
@@ -1908,6 +1946,13 @@ double TimelineController::fps() const
 
 void TimelineController::editItemDuration(int id)
 {
+    if (id == -1) {
+        id = getMainSelectedItem(false, true);
+    }
+    if (id == -1) {
+        pCore->displayMessage(i18n("No item to edit"), InformationMessage, 500);
+        return;
+    }
     int start = m_model->getItemPosition(id);
     int in = 0;
     int duration = m_model->getItemPlaytime(id);
@@ -2004,10 +2049,15 @@ void TimelineController::updateClipActions()
             act->setEnabled(false);
         }
         emit timelineClipSelected(false);
+        // nothing selected
+        emit showItemEffectStack(QString(), nullptr, QSize(), false);
         return;
     }
     std::shared_ptr<ClipModel> clip(nullptr);
     int item = *m_model->getCurrentSelection().begin();
+    if (m_model->getCurrentSelection().size() == 1 && (m_model->isClip(item) || m_model->isComposition(item))) {
+        showAsset(item);
+    }
     if (m_model->isClip(item)) {
         clip = m_model->getClipPtr(item);
     }
@@ -2051,20 +2101,15 @@ void TimelineController::grabCurrent()
         return;
     }
     int id = *m_model->getCurrentSelection().begin();
+    while (m_model->isGroup(id)) {
+        id = *m_model->m_groups->getLeaves(id).begin();
+    }
     if (m_model->isClip(id)) {
         std::shared_ptr<ClipModel> clip = m_model->getClipPtr(id);
         clip->setGrab(!clip->isGrabbed());
-        QModelIndex ix = m_model->makeClipIndexFromID(id);
-        if (ix.isValid()) {
-            m_model->dataChanged(ix, ix, {TimelineItemModel::GrabbedRole});
-        }
     } else if (m_model->isComposition(id)) {
         std::shared_ptr<CompositionModel> clip = m_model->getCompositionPtr(id);
         clip->setGrab(!clip->isGrabbed());
-        QModelIndex ix = m_model->makeCompositionIndexFromID(id);
-        if (ix.isValid()) {
-            m_model->dataChanged(ix, ix, {TimelineItemModel::GrabbedRole});
-        }
     }
 }
 
@@ -2398,14 +2443,19 @@ void TimelineController::finishRecording(const QString &recordedFile)
         bool res = false;
         if (m_recordStart.second > 0) {
             // Limited space on track
-            QString binClipId = QString("%1/%2/%3").arg(binId).arg(0).arg(m_recordStart.second - 1);
+            std::shared_ptr<ProjectClip> clip = pCore->bin()->getBinClip(binId);
+            if (!clip) {
+                return;
+            }
+            int out = qMin((int)clip->frameDuration() - 1, m_recordStart.second - 1);
+            QString binClipId = QString("%1/%2/%3").arg(binId).arg(0).arg(out);
             res = m_model->requestClipInsertion(binClipId, m_recordTrack, m_recordStart.first, id, true, true, false);
         } else {
             res = m_model->requestClipInsertion(binId, m_recordTrack, m_recordStart.first, id, true, true, false);
         }
     };
-    QString binId = ClipCreator::createClipFromFile(recordedFile, pCore->projectItemModel()->getRootFolder()->clipId(), pCore->projectItemModel(), undo,
-                                                    redo, callBack);
+    QString binId =
+        ClipCreator::createClipFromFile(recordedFile, pCore->projectItemModel()->getRootFolder()->clipId(), pCore->projectItemModel(), undo, redo, callBack);
     if (binId != QStringLiteral("-1")) {
         pCore->pushUndo(undo, redo, i18n("Record audio"));
     }
