@@ -42,13 +42,16 @@
 #include <QWidget>
 
 FlowLayout::FlowLayout(QWidget *parent, int margin, int hSpacing, int vSpacing)
-    : QLayout(parent), m_hSpace(hSpacing), m_vSpace(vSpacing)
+    : QLayout(parent)
+    , m_hSpace(hSpacing)
+    , m_vSpace(vSpacing)
 {
     setContentsMargins(margin, margin, margin, margin);
 }
 
 FlowLayout::FlowLayout(int margin, int hSpacing, int vSpacing)
-    : m_hSpace(hSpacing), m_vSpace(vSpacing)
+    : m_hSpace(hSpacing)
+    , m_vSpace(vSpacing)
 {
     setContentsMargins(margin, margin, margin, margin);
 }
@@ -56,51 +59,48 @@ FlowLayout::FlowLayout(int margin, int hSpacing, int vSpacing)
 FlowLayout::~FlowLayout()
 {
     QLayoutItem *item;
-    while ((item = takeAt(0))) {
+    while ((item = takeAt(0)) != nullptr) {
         delete item;
     }
 }
 
 void FlowLayout::addItem(QLayoutItem *item)
 {
-    itemList.append(item);
+    m_itemList.append(item);
 }
 
 int FlowLayout::horizontalSpacing() const
 {
     if (m_hSpace >= 0) {
         return m_hSpace;
-    } else {
-        return smartSpacing(QStyle::PM_LayoutHorizontalSpacing);
     }
+    return smartSpacing(QStyle::PM_LayoutHorizontalSpacing);
 }
 
 int FlowLayout::verticalSpacing() const
 {
     if (m_vSpace >= 0) {
         return m_vSpace;
-    } else {
-        return smartSpacing(QStyle::PM_LayoutVerticalSpacing);
     }
+    return smartSpacing(QStyle::PM_LayoutVerticalSpacing);
 }
 
 int FlowLayout::count() const
 {
-    return itemList.size();
+    return m_itemList.size();
 }
 
 QLayoutItem *FlowLayout::itemAt(int index) const
 {
-    return itemList.value(index);
+    return m_itemList.value(index);
 }
 
 QLayoutItem *FlowLayout::takeAt(int index)
 {
-    if (index >= 0 && index < itemList.size()) {
-        return itemList.takeAt(index);
-    } else {
-        return nullptr;
+    if (index >= 0 && index < m_itemList.size()) {
+        return m_itemList.takeAt(index);
     }
+    return nullptr;
 }
 
 Qt::Orientations FlowLayout::expandingDirections() const
@@ -133,8 +133,7 @@ QSize FlowLayout::sizeHint() const
 QSize FlowLayout::minimumSize() const
 {
     QSize size;
-    QLayoutItem *item;
-    foreach (item, itemList) {
+    for (QLayoutItem *item : m_itemList) {
         size = size.expandedTo(item->minimumSize());
     }
 
@@ -151,17 +150,12 @@ int FlowLayout::doLayout(const QRect &rect, bool testOnly) const
     int y = effectiveRect.y();
     int lineHeight = 0;
 
-    QLayoutItem *item;
-    foreach (item, itemList) {
+    for (QLayoutItem *item : m_itemList) {
         QWidget *wid = item->widget();
         int spaceX = horizontalSpacing();
-        if (spaceX == -1)
-            spaceX = wid->style()->layoutSpacing(
-                         QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Horizontal);
+        if (spaceX == -1) spaceX = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Horizontal);
         int spaceY = verticalSpacing();
-        if (spaceY == -1)
-            spaceY = wid->style()->layoutSpacing(
-                         QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Vertical);
+        if (spaceY == -1) spaceY = wid->style()->layoutSpacing(QSizePolicy::PushButton, QSizePolicy::PushButton, Qt::Vertical);
         int nextX = x + item->sizeHint().width() + spaceX;
         if (nextX - spaceX > effectiveRect.right() && lineHeight > 0) {
             x = effectiveRect.x();
@@ -184,10 +178,10 @@ int FlowLayout::smartSpacing(QStyle::PixelMetric pm) const
     QObject *parent = this->parent();
     if (!parent) {
         return -1;
-    } else if (parent->isWidgetType()) {
-        QWidget *pw = static_cast<QWidget *>(parent);
-        return pw->style()->pixelMetric(pm, nullptr, pw);
-    } else {
-        return static_cast<QLayout *>(parent)->spacing();
     }
+    if (parent->isWidgetType()) {
+        auto *pw = static_cast<QWidget *>(parent);
+        return pw->style()->pixelMetric(pm, nullptr, pw);
+    }
+    return static_cast<QLayout *>(parent)->spacing();
 }
